ytree\.arbor\.arbor\.Arbor
==========================

.. currentmodule:: ytree.arbor.arbor

.. autoclass:: Arbor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Arbor.__init__
      ~Arbor.add_alias_field
      ~Arbor.add_analysis_field
      ~Arbor.add_derived_field
      ~Arbor.is_grown
      ~Arbor.is_setup
      ~Arbor.save_arbor
      ~Arbor.select_halos
      ~Arbor.set_selector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Arbor.arr
      ~Arbor.box_size
      ~Arbor.field_info
      ~Arbor.hubble_constant
      ~Arbor.quan
      ~Arbor.size
      ~Arbor.trees
      ~Arbor.unit_registry
   
   